@@ -505,16 +505,19 @@ Example: fork a process and wait for it
 
    $w = AnyEvent->idle (cb => <callback>);
 
-Sometimes there is a need to do something, but it is not so important
-to do it instantly, but only when there is nothing better to do. This
-"nothing better to do" is usually defined to be "no other events need
-attention by the event loop".
+Repeatedly invoke the callback after the process becomes idle, until
+either the watcher is destroyed or new events have been detected.
 
-Idle watchers ideally get invoked when the event loop has nothing
-better to do, just before it would block the process to wait for new
-events. Instead of blocking, the idle watcher is invoked.
+Idle watchers are useful when there is a need to do something, but it
+is not so important (or wise) to do it instantly. The callback will be
+invoked only when there is "nothing better to do", which is usually
+defined as "all outstanding events have been handled and no new events
+have been detected". That means that idle watchers ideally get invoked
+when the event loop has just polled for new events but none have been
+detected. Instead of blocking to wait for more events, the idle watchers
+will be invoked.
 
-Most event loops unfortunately do not really support idle watchers (only
+Unfortunately, most event loops do not really support idle watchers (only
 EV, Event and Glib do it in a usable fashion) - for the rest, AnyEvent
 will simply call the callback "from time to time".
 
@@ -1155,7 +1158,7 @@ BEGIN { AnyEvent::common_sense }
 
 use Carp ();
 
-our $VERSION = '5.23';
+our $VERSION = '5.24';
 our $MODEL;
 
 our $AUTOLOAD;
@@ -1166,8 +1169,9 @@ our @REGISTRY;
 our $VERBOSE;
 
 BEGIN {
-   eval "sub WIN32(){ " . (($^O =~ /mswin32/i)*1) ." }";
-   eval "sub TAINT(){ " . (${^TAINT}*1) . " }";
+   eval "sub CYGWIN(){" . (($^O =~ /cygwin/i) *1) . "}";
+   eval "sub WIN32 (){" . (($^O =~ /mswin32/i)*1) . "}";
+   eval "sub TAINT (){" . (${^TAINT}          *1) . "}";
 
    delete @ENV{grep /^PERL_ANYEVENT_/, keys %ENV}
       if ${^TAINT};
@@ -2536,12 +2540,17 @@ try to use a monotonic clock for timing stability.
 =head1 FORK
 
 Most event libraries are not fork-safe. The ones who are usually are
-because they rely on inefficient but fork-safe C<select> or C<poll>
-calls. Only L<EV> is fully fork-aware.
+because they rely on inefficient but fork-safe C<select> or C<poll> calls
+- higher performance APIs such as BSD's kqueue or the dreaded Linux epoll
+are usually badly thought-out hacks that are incompatible with fork in
+one way or another. Only L<EV> is fully fork-aware and ensures that you
+continue event-processing in both parent and child (or both, if you know
+what you are doing).
 
-This means that, in general, you cannot fork and do event processing
-in the child if a watcher was created before the fork (which in turn
-initialises the event library).
+This means that, in general, you cannot fork and do event processing in
+the child if the event library was initialised before the fork (which
+usually happens when the first AnyEvent watcher is created, or the library
+is loaded).
 
 If you have to fork, you must either do so I<before> creating your first
 watcher OR you must not use AnyEvent at all in the child OR you must do
@@ -2551,7 +2560,10 @@ The problem of doing event processing in the parent I<and> the child
 is much more complicated: even for backends that I<are> fork-aware or
 fork-safe, their behaviour is not usually what you want: fork clones all
 watchers, that means all timers, I/O watchers etc. are active in both
-parent and child, which is almost never what you want.
+parent and child, which is almost never what you want. USing C<exec>
+to start worker children from some kind of manage rprocess is usually
+preferred, because it is much easier and cleaner, at the expense of having
+to have another binary.
 
 
 =head1 SECURITY CONSIDERATIONS
